@@ -3,5 +3,5 @@ from abc import ABCMeta, abstractmethod
 
 class MetricsManagerGateway(metaclass=ABCMeta):
     @abstractmethod
-    def send_metrics(self, config_tool, tool, file_path):
+    def send_metrics(self, config_tool, module, file_path):
         "send_metrics"
